@@ -16,7 +16,7 @@ async def exec_access(inc: InputContext,
     match inc.request.method:
         case "GET":
             kwargs = inc.r_kwargs
-            entity_id = kwargs.pop("entity_id", default=None)
+            entity_id = kwargs.pop("entity_id", None)
             if entity_id is None:
                 limit = inc.request.args.get("limit")
                 offset = inc.request.args.get("offset")
